;+
;
; .. _interpol_correc.pro:
;
; ===================
; interpol_correc.pro
; ===================
;
; DESCRIPTION
; ===========
;
; interpolation des tableaux de correction amsub (calcules sur
; echantillonnage amsua) sur les 90 points de la fauchee amsub
;
; read :file:`${PROJECT}/src/dataref_amsu/CORR_[LAND|SEA]_AMSU[AB]_JUIL2006.DAT`
; containing correction for land and sea. ++ ref. algo fatima karbou
;
; .. only:: man
;
;    Figure is visible on PDF and HTML documents only.
;
; .. only:: html or latex
;
;     .. graphviz::
;
;        digraph interpol_correc {
;
;           amsu_b_cor_land [shape=diamond,fontname=Courier,label="${PROJECT}/src/dataref_amsu/CORR_LAND_AMSUB_JUIL2006.DAT"];
;           amsu_b_cor_sea [shape=diamond,fontname=Courier,label="${PROJECT}/src/dataref_amsu/CORR_SEA_AMSUB_JUIL2006.DAT"];
;
;           interpol_correc [shape=box,
;           fontname=Courier,
;           color=blue,
;           URL="http://forge.ipsl.jussieu.fr/varamma/browser/trunk/src/interpol_correc.pro",
;           label="${PROJECT}/src/interpol_correc.pro"];
;
;           {amsu_b_cor_land amsu_b_cor_sea} -> {interpol_correc};
;
;           }
;
;
; SEE ALSO
; ========
;
; :ref:`data_amsu`
;
; Called by :ref:`correct_nadir_amsu.pro`
;
; EXAMPLES
; ========
;
; ::
;
;    interpol_correc,cor_lb,cor_sb
;    print, cor_lb
;    print, cor_sb
;
;
; TODO
; ====
;
;
; on peut changer le codage en dur des fauchees ou demi-fauchees, mais
; programme adapte a AMSUA et AMSUB, pas MHS (90 points, mais fauchee
; un peu plus large)
;
; utiliser ce programme pour la correction nadir pour amsua et
; amsub, car peut retourner la fonction de correction et la taille des
; EFOV (tache au sol effective)
;
; exit with error status if wrong parameter
;
; coding rules
;
; hard coded information
;
; EVOLUTIONS
; ==========
;
; - lelod 20120620
;   amelioration du code et introduction des corrections par
;   satellite pour amsub
; impasse sur difference amsub - mhs a ce niveau
; remis les donnees de correction dans data_raf_amsu pour update VARAMMA
;
; - lelod 20120525
;
; analyse de la correction nadir : refonte et calcul par satellite
; avec adaptation  la region choisie (Afrique de l'ouest)
; changement a faire dans extract_amsua.pro
; $Id$
;
; $URL$
;
; - fplod 20120416
;
;   * correction for correction reading if a5 vs a
;
; - fplod 20120106
;
;   * reprise des modifs lelod : changement de localisation des fichiers de correction
;
; - lelod 20111209
;
;   * modif organisation avec separation des traitements un seul canal traite
;
; - lelod 20111019
;
;   * fonction pixelsize fait le calcul des tailles des taches au sol a et
;     b, et ressort le tableau correspondant sur la fauchee
;     appel en dbut de interpol
;
; - fplod 20110810T084245Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * correct_nadir_LE06 has been replaced by correct_nadir_amsu
;
; - pinsard 2011-05-26T15:40:51Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * rewrite header (scratched by ?, how ?)
;   * add cm_project
;
; - fplod 20110525T083313Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * header
;
; - lelod 2011052?
;
;   * creation
;
;-
PRO interpol_correc,numch,nbpix,cor_l,cor_s,swath,track
;
@cm_project
nomcanal=strmid(numch,0,1)
numcanal=0
reads, strmid(numch,1,1),numcanal,format='(i1.1)'

pixelsize,pixatot,pixbtot,alongatot,alongbtot
if nomcanal eq 'a' then begin
   swath=pixatot
   track=alongatot
endif else begin
   swath=pixbtot
   track=alongbtot
endelse

; parametres AMSU et calcul de la geometrie de la fauchee
; pourinterpolation de la correction (calculee sur geometrie AMSUA) a AMSUB
nfova=30
nfovb=90
ndfova=nfova/2 ; 15
ndfovb=nfovb/2 ; 45
; cas AMSUA
fova=fltarr(ndfova)
alonga=alongatot[ndfova:nfova-1]
pixa=pixatot[ndfova:nfova-1]
;ifov nadir : diametre (km)
ifova=48.05
; position dans la fauchee: premier point au nadir a ifov/2
; zone pixel : ellipse de grand axe pixb et petit axe alongb
coefa=1 ; recouvrement des pixels dans la fauchee
fova(0)=ifova/2.
for i=1,ndfova-1 do fova(i)=fova(i-1)+coefa*(pixa(i-1)/2 +pixa(i)/2) ; verifier!!!
fov_a=fltarr(ndfova)
;fov_a(14)=fova(0)
;for i=0,13 do fov_a(13-i)=fov_a(14-i)+coefa*(pixa(13-i)/2 +pixa(14-i)/2)
for i=0,ndfova-1 do fov_a(i)=-fova(ndfova-1-i)

fovb=fltarr(ndfovb)
alongb=fltarr(ndfovb)
alongb=alongbtot[ndfovb:nfovb-1] ; verifier l'intervalle!!!!!
pixb=pixbtot[ndfovb:nfovb-1]
;ifov nadir : diametre (km)
ifovb=16.
coefb=0.8
fovb(0)=ifovb/2.
for i=1,ndfovb-1 do fovb(i)=fovb(i-1)+coefb*(pixb(i-1)/2 +pixb(i)/2)
fov_b=fltarr(ndfovb)
;fov_b(44)=fovb(0)
;for i=0,43 do  fov_b(43-i)=fov_b(44-i)+coefb*(pixb(43-i)/2 +pixb(44-i)/2)
for i=0,ndfovb-1 do fov_b(i)=-fovb(ndfovb-1-i)


path = project_env + '/src/dataref_amsu/'
; lecture des fichiers d'ajustement au nadir pour AMSUA et B
; noaa17 elimine - lecture pour les 5 satellites utilises N15, 16, 18, 19, M02
if nomcanal eq 'a' then begin
   instr='A'
   nfov=nfova
endif else begin
   instr='B'
   nfov=nfovb
endelse
cor_l=fltarr(nfov,5)
cor_s=fltarr(nfov,5)
cor_sea15=path+'CORR_SEA_AMSU'+instr+strmid(numch,1,1)+'_DataFromJune2010_Afrique_NOAA15.DAT'
cor_land15=path+'CORR_LAND_AMSU'+instr+strmid(numch,1,1)+'_DataFromJune2010_Afrique_NOAA15.DAT'
cor_sea16=path+'CORR_SEA_AMSU'+instr+strmid(numch,1,1)+'_DataFromJune2010_Afrique_NOAA16.DAT'
cor_land16=path+'CORR_LAND_AMSU'+instr+strmid(numch,1,1)+'_DataFromJune2010_Afrique_NOAA16.DAT'
cor_sea18=path+'CORR_SEA_AMSU'+instr+strmid(numch,1,1)+'_DataFromJune2010_Afrique_NOAA18.DAT'
cor_land18=path+'CORR_LAND_AMSU'+instr+strmid(numch,1,1)+'_DataFromJune2010_Afrique_NOAA18.DAT'
cor_sea19=path+'CORR_SEA_AMSU'+instr+strmid(numch,1,1)+'_DataFromJune2010_Afrique_NOAA19.DAT'
cor_land19=path+'CORR_LAND_AMSU'+instr+strmid(numch,1,1)+'_DataFromJune2010_Afrique_NOAA19.DAT'
cor_seaM2=path+'CORR_SEA_AMSU'+instr+strmid(numch,1,1)+'_DataFromJune2010_Afrique_METOP.DAT'
cor_landM2=path+'CORR_LAND_AMSU'+instr+strmid(numch,1,1)+'_DataFromJune2010_Afrique_METOP.DAT'
listcorr_l=[cor_land15,cor_land16,cor_land18,cor_land19,cor_landM2]
for nosat=0,4 do begin
   corrland=listcorr_l[nosat]
   openr, lun1,corrland, /get_lun, ERROR = error
   IF (error NE 0) then begin
      ras = report(['eee : can not open for reading '$
                    + '!C' $
                    + 'code : ' + !ERROR_STATE.MSG $
                    + corrland])
      STOP
   ENDIF
   readf, lun1, t1,t2,t3,t4,t5,t6,t7,t8,t9,t10,$
          t11,t12,t13,t14,t15,t16,t17,t18,t19,t20,$
          t21,t22,t23,t24,t25,t26,t27,t28,t29,t30
   a=[t1,t2,t3,t4,t5,t6,t7,t8,t9,t10,$
      t11,t12,t13,t14,t15,t16,t17,t18,t19,t20,$
      t21,t22,t23,t24,t25,t26,t27,t28,t29,t30]
   if nomcanal eq 'a' then begin
      cor_l[*,nosat]=interpol(a,nfova,/lsquadratic) 
   endif else begin
      cor_l[ndfovb:nfovb-1,nosat]=interpol(a[ndfova:nfova-1],fova,fovb,/spline)
      cor_l[0:ndfovb-1,nosat]=interpol(a[0:ndfova-1],fov_a,fov_b,/spline)
   endelse
   free_lun, lun1
endfor

listcorr_s=[cor_sea15,cor_sea16,cor_sea18,cor_sea19,cor_seaM2]
for nosat=0,4 do begin
   corrsea=listcorr_s[nosat]
   openr, lun1,corrsea, /get_lun, ERROR = error
   IF (error NE 0) then begin
      ras = report(['eee : can not open for reading '$
                    + '!C' $
                    + corrsea])
      STOP
   ENDIF
   readf, lun1, t1,t2,t3,t4,t5,$
          t6,t7,t8,t9,t10,$
          t11,t12,t13,t14,t15,$
          t16,t17,t18,t19,t20,$
          t21,t22,t23,t24,t25,$
          t26,t27,t28,t29,t30
   
   a=[t1,t2,t3,t4,t5,$
      t6,t7,t8,t9,t10,$
      t11,t12,t13,t14,t15,$
      t16,t17,t18,t19,t20,$
      t21,t22,t23,t24,t25,$
      t26,t27,t28,t29,t30]
   free_lun, lun1
   
   if nomcanal eq 'a' then begin
      cor_s[*,nosat]=interpol(a,nfova,/lsquadratic) 
   endif else begin
      cor_s[ndfovb:nfovb-1,nosat]=interpol(a[ndfova:nfova-1],fova,fovb,/spline)
      cor_s[0:ndfovb-1,nosat]=interpol(a[0:ndfova-1],fov_a,fov_b,/spline)
   endelse
   free_lun, lun1
endfor

end
